@@ -41,6 +41,32 @@ if making too many processes, so capping it can help."
 
 ;;;; Subroutines
 
+(defalias 'el-job-ng--sit-until 'el-job-ng-sit-until)
+(defmacro el-job-ng-sit-until (test max-secs &optional message)
+  "Block until form TEST evaluates to non-nil, or MAX-SECS elapse.
+Either way, return the last TEST result.
+In other words, a nil return value means it has timed out.
+
+While blocking input to Emacs, keep MESSAGE visible in the echo area.
+MESSAGE can be a string, or a form that evaluates to a string.
+
+Both TEST and MESSAGE should be cheap forms, since they are evaluated
+repeatedly and cannot themselves trigger the time-out if they hang.
+A typical TEST would check if something in the environment has changed."
+  (let ((deadline (gensym "deadline"))
+        (last (gensym "last")))
+    `(let ((,deadline (time-add (current-time) ,max-secs))
+           ,last)
+       (catch 'timeout
+         (while (null (setq ,last ,test))
+           (when (time-less-p ,deadline (current-time))
+             (throw 'timeout nil))
+           ,(when message `(unless (current-message)
+                             (message "%s" ,message)))
+           (discard-input)
+           (sit-for 0.1)))
+       ,last)))
+
 (defvar el-job-ng--debug-level 0
   "Increase this to 1 or 2 to see more debug messages.")
 
@@ -137,6 +163,28 @@ Unlike `locate-library', this can actually find the .eln."
         (locate-library name)
         (error "el-job-ng: Library not found: %S" name))))
 
+(defvar el-job-ng--supported nil)
+(defun el-job-ng--supported-p ()
+  "Return t if Emacs can create processes successfully."
+  (with-memoization el-job-ng--supported
+    (let ((default-directory invocation-directory)
+          (emacs (expand-file-name invocation-name invocation-directory))
+          sentinel-invoked supported)
+      (with-local-quit ;; "Blocking call to accept-process-output with quit inhibited!! [7 times]"
+        (accept-process-output
+         (make-process :name "el-job-init-test"
+                       :connection-type 'pipe
+                       :command (list emacs "--quick" "--batch")
+                       :sentinel (lambda (proc _)
+                                   (setq sentinel-invoked t)
+                                   (when (and (processp proc)
+                                              (eq (process-status proc) 'exit)
+                                              (eq (process-exit-status proc) 0))
+                                     (setq supported t))))
+         nil nil t)
+        (el-job-ng-sit-until sentinel-invoked 20)
+        supported))))
+
 
 ;;;; Entry point
 
@@ -200,10 +248,10 @@ ID can also be passed to these helpers:
 - `el-job-ng-kill-keep-bufs'
 - `el-job-ng-processes'
 - `el-job-ng-stderr'"
+  (when (null inputs)
+    (cl-return-from el-job-ng-run))
   (unless (symbolp funcall-per-input)
     (error "FUNCALL-PER-INPUT must be defined in some file loaded via REQUIRE"))
-  (unless (and inputs (listp inputs))
-    (error "INPUTS must be a non-empty list"))
   (when (numberp id)
     (error "Numeric ID is reserved for internal use"))
   ;; Clean-up defunct anonymous jobs
@@ -326,7 +374,7 @@ assume the process buffer contains a readable Lisp expression
 and run `el-job-ng--handle-finished-child'."
   (let* ((buf (process-buffer proc))
          (job (el-job-ng-get-job proc))
-         (id (oref job id))
+         (id (and job (oref job id)))
          (info (concat (format "Process %s" event) ;; EVENT contains "\n"
                        (format "status:      %S\n" (process-status proc))
                        (format "exit status: %d\n" (process-exit-status proc))
@@ -334,8 +382,13 @@ and run `el-job-ng--handle-finished-child'."
                        (format "el-job id:   %S" id)))
          (info+tip (concat info "\n"
                            (format "tip:         check the hidden buffer named (note leading space): \"%s\""
-                                   (buffer-name (oref job stderr))))))
-    (cond ((or (eq (process-status proc) 'run)
+                                   (buffer-name (and job (oref job stderr)))))))
+    (cond ((not job)
+           (el-job-ng--dbg 0 "Could not find job associated with process %S%s"
+                           proc
+                           ", did something kill the process buffer before sentinel could be called?"))
+
+          ((or (eq (process-status proc) 'run)
                (equal event "killed\n")
                (equal event "deleted\n"))
            ;; Situation normal, often arrive here due to `delete-process'.
@@ -351,6 +404,12 @@ and run `el-job-ng--handle-finished-child'."
            ;; whatever to the window configuration.
            (el-job-ng--handle-finished-child proc buf job))
 
+          ;; "exited abnormally with code 1\n"
+          ;; https://github.com/meedstrom/org-node/issues/96#issuecomment-2887497938
+          ((not (el-job-ng--supported-p))
+           (el-job-ng-kill-keep-bufs id)
+           (error "Emacs seems unable to create processes, so el-job will not work"))
+
           (t
            (el-job-ng--dbg 0 "%s" info+tip)
            (el-job-ng-kill-keep-bufs id)))))
@@ -383,31 +442,6 @@ specified in `el-job-ng-run'."
 
 ;;;; API
 
-(defmacro el-job-ng-sit-until (test max-secs &optional message)
-  "Block until form TEST evaluates to non-nil, or MAX-SECS elapse.
-Either way, return the last TEST result.
-In other words, a nil return value means it has timed out.
-
-While blocking input to Emacs, keep MESSAGE visible in the echo area.
-MESSAGE can be a string, or a form that evaluates to a string.
-
-Both TEST and MESSAGE should be cheap forms, since they are evaluated
-repeatedly and cannot themselves trigger the time-out if they hang.
-A typical TEST would check if something in the environment has changed."
-  (let ((deadline (gensym "deadline"))
-        (last (gensym "last")))
-    `(let ((,deadline (time-add (current-time) ,max-secs))
-           ,last)
-       (catch 'timeout
-         (while (null (setq ,last ,test))
-           (when (time-less-p ,deadline (current-time))
-             (throw 'timeout nil))
-           ,(when message `(unless (current-message)
-                             (message "%s" ,message)))
-           (discard-input)
-           (sit-for 0.1)))
-       ,last)))
-
 (defun el-job-ng-await (id max-secs &optional message)
   "Like `el-job-ng-sit-until' but take ID and return t if job finishes.
 MAX-SECS and MESSAGE as in `el-job-ng-sit-until'."
@@ -438,6 +472,7 @@ ID, MAX-SECS and MESSAGE as in `el-job-ng-await'."
 (defun el-job-ng-kill (id)
   "Kill processes for job ID and their buffers."
   (dolist (proc (el-job-ng-processes id))
+    (set-process-sentinel proc #'ignore)
     (let ((buf (process-buffer proc)))
       (if (buffer-live-p buf)
           (kill-buffer buf)
@@ -449,6 +484,7 @@ ID, MAX-SECS and MESSAGE as in `el-job-ng-await'."
 (defun el-job-ng-kill-keep-bufs (id)
   "Kill processes for job ID."
   (dolist (proc (el-job-ng-processes id))
+    (set-process-sentinel proc #'ignore)
     (delete-process proc)))
 
 (defun el-job-ng-stderr (id)
